/*********************************************
Compiler            : CodeVision
Hardware            : AVR-Ctrl + LDR
Chip type           : AT90S8535
Clock frequency     : 8,000000 MHz
Memory model        : Small
Internal SRAM size  : 512
External SRAM size  : 0
Data Stack size     : 128
*********************************************/

#include <90s8535.h>             
#include <stdio.h>
#include <delay.h>

// Alphanumeric LCD Module functions
#asm
   .equ __lcd_port=0x15
#endasm
#include <lcd.h>

#define FIRST_ADC_INPUT 0
#define LAST_ADC_INPUT 0
unsigned int adc_data[LAST_ADC_INPUT-FIRST_ADC_INPUT+1];
#define ADC_VREF_TYPE 0x00
// ADC interrupt service routine
// with auto input scanning
#pragma savereg-
interrupt [ADC_INT] void adc_isr(void)
{
#asm
    push r26
    push r27
    push r30
    push r31
    in   r30,sreg
    push r30
#endasm
register static unsigned char input_index=0;
// Read the ADC conversion result
adc_data[input_index]=ADCW;
// Select next ADC input
if (++input_index>(LAST_ADC_INPUT-FIRST_ADC_INPUT))
   input_index=0;
ADMUX=input_index+FIRST_ADC_INPUT|ADC_VREF_TYPE;
// Start the next ADC conversion
ADCSR.6=1;
#asm
    pop  r30
    out  sreg,r30
    pop  r31
    pop  r30
    pop  r27
    pop  r26
#endasm
}
#pragma savereg+

// Declare your global variables here

void main(void)
{
// Declare your local variables here    
char text[16];
unsigned int wert;
                  
delay_ms(100);
// Input/Output Ports initialization
// Port A
PORTA=0x00;
DDRA=0x00;

// Port B
PORTB=0x00;
DDRB=0x00;

// Port C
PORTC=0x00;
DDRC=0x00;

// Port D
PORTD=0x00;
DDRD=0x00;

// Timer/Counter 0 initialization
// Clock source: System Clock
// Clock value: Timer 0 Stopped
// Mode: Output Compare
// OC0 output: Disconnected
TCCR0=0x00;
TCNT0=0x00;

// Timer/Counter 1 initialization
// Clock source: System Clock
// Clock value: Timer 1 Stopped
// Mode: Output Compare
// OC1A output: Discon.
// OC1B output: Discon.
// Noise Canceler: Off
// Input Capture on Falling Edge
TCCR1A=0x00;
TCCR1B=0x00;
TCNT1H=0x00;
TCNT1L=0x00;
OCR1AH=0x00;
OCR1AL=0x00;
OCR1BH=0x00;
OCR1BL=0x00;

// Timer/Counter 2 initialization
// Clock source: System Clock
// Clock value: Timer 2 Stopped
// Mode: Output Compare
// OC2 output: Disconnected
TCCR2=0x00;
ASSR=0x00;
TCNT2=0x00;
OCR2=0x00;

// External Interrupt(s) initialization
// INT0: Off
// INT1: Off
GIMSK=0x00;
MCUCR=0x00;

// Timer(s)/Counter(s) Interrupt(s) initialization
TIMSK=0x00;

// Analog Comparator initialization
// Analog Comparator: Off
// Analog Comparator Input Capture by Timer/Counter 1: Off
ACSR=0x80;

// ADC initialization
// ADC Clock frequency: 62,500 kHz
ADMUX=FIRST_ADC_INPUT|ADC_VREF_TYPE;
ADCSR=0xCF;

// LCD module initialization
lcd_init(16);

// Global enable interrupts
#asm("sei")

while (1)
      {
        wert = adc_data[0];
        sprintf(text," AD: %i",wert);
        lcd_gotoxy(0,0);
        lcd_puts(text);
                        
        lcd_gotoxy(0,1);
        if (wert > 812) lcd_putsf("hell  ");
        else if (wert > 700) lcd_putsf("na ja");
        else lcd_putsf("dunkel");
        delay_ms(100);
      };
}
